package it.unibo.tw0809.utils;

import java.io.StringReader;
import java.net.URL;

import javax.xml.XMLConstants;
import javax.xml.transform.Source;
import javax.xml.transform.stream.StreamSource;
import javax.xml.validation.Schema;
import javax.xml.validation.SchemaFactory;
import javax.xml.validation.Validator;

import org.xml.sax.SAXException;

public class MyValidator {

	public static boolean validate(String data, String schema_uri) {

		try {
			// 1. Lookup a factory for the W3C XML Schema language
			SchemaFactory factory = SchemaFactory.newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI);
			// SchemaFactory factory = SchemaFactory.newInstance("http://www.w3.org/2001/XMLSchema");	SAME AS ABOVE
			
			// SINCE JDK 1.4, DTD VALIDATION IS DEFINED BUT NOT IMPLEMENTED!
			// SchemaFactory factory = SchemaFactory.newInstance(XMLConstants.XML_DTD_NS_URI);			IF USING OBSOLETE DTD INSTEAD OF XSD 
			
			// 2. Compile the schema. 
			// Here the schema is loaded from a java.io.File, but you could use 
			// a java.net.URL or a javax.xml.transform.Source instead.
			URL schemaLocation = new URL(schema_uri);
			Schema schema = factory.newSchema(schemaLocation);
			
			// 3. Get a validator from the schema.
			Validator validator = schema.newValidator();
			
			// 4. Parse the document you want to check.
			Source source = new StreamSource(new StringReader(data));
			
			// 5. Check the document
			try {
			    validator.validate(source);
			    return true;
			}
			catch (SAXException ex) {
			    return false;
			}  
			
		}
		catch (Exception e) {
		    return false;
		}

	}

}
